InternedCategory

Struct InternedCategory 

pub struct InternedCategory { /* private fields */ }
A binary-stable, transparent representation of fxt::InternedCategory.

Under the C++ ABI, fxt::InternedCategory consists of:

  1. A reference to InternedString, represented as a &'static InternedString (8 bytes).
  2. A mutable atomic u32 representing the category’s index (4 bytes).
  3. 4 bytes of padding (implied by alignment rules on 64-bit platforms).

Implementations

Source

impl InternedCategory

pub const INVALID_INDEX: u32 = u32::MAX

The index value representing an invalid or unregistered category.

pub const fn new(label: &'static InternedString) -> Self

Creates a new InternedCategory from a reference to an InternedString.

pub fn label(&self) -> &'static InternedString

Returns a reference to the underlying InternedString.

pub fn string(&self) -> &'static CStr

Returns the static category name as a safe C string reference.

pub fn index(&self) -> u32

Returns the index associated with the category.

pub fn set_index(&self, index: u32, expected: u32)

Sets the index for the category if it has the expected previous value. This provides a simple way to prevent re-initialization if RegisterCategories() is called more than once, while also providing a way to override the value. This can be removed once the index can be automatically derived from the section offset when the kernel supports extensible categories.