Struct kstring::KStringCow [−][src]
#[repr(transparent)]pub struct KStringCow<'s> { /* fields omitted */ }Expand description
A reference to a UTF-8 encoded, immutable string.
Implementations
Create an owned KStringCow.
Create an owned KStringCow.
Create a reference to a 'static data.
Get a reference to the KString.
Clone the data into an owned-type.
Convert to a mutable string type, cloning the data if necessary.
Convert to a mutable string type, cloning the data if necessary.
Convert to a Cow str