pub struct InternedString { /* private fields */ }Expand description
A binary-stable, transparent representation of fxt::InternedString.
This structure has the exact same memory layout as the C++ fxt::InternedString
(which is a single const char* pointer pointing to a null-terminated string).
Placing instances of this structure in the special linker section __fxt_interned_string_table
allows them to sit contiguous alongside C++’s own interned strings in the global
string table segment, meaning their trace-ID calculations (this - section_begin)
are safe, exact, and valid.
Implementations